@@ -1247,10 +1247,6 @@ def after_install(options, home_dir):
     else:
         bin_dir = join(home_dir, 'bin')
     subprocess.call([join(bin_dir, 'easy_install'), 'paver==1.0.3'])
-    subprocess.call([join(bin_dir, 'easy_install'), 'nose>=1.0,<1.0.99'])
-    subprocess.call([join(bin_dir, 'easy_install'), 'mock>=0.6,<0.6.99'])
-    subprocess.call([join(bin_dir, 'easy_install'), 'unittest2>=0.5.1,<0.5.99'])
-    subprocess.call([join(bin_dir, 'easy_install'), 'strait>=0.5.1,<0.5.99'])
     subprocess.call([join(bin_dir, 'easy_install'), 'virtualenv>=1.5.1,<1.5.99'])
     subprocess.call([join(bin_dir, 'easy_install'), 'ipython>=0.10.1,<0.10.99'])
     subprocess.call([join(bin_dir, 'easy_install'), 'Sphinx>=1.0.5,<1.0.99'])
