@@ -48,7 +48,7 @@ from zope import interface
 ## pylint: enable=E0611
 
 #---  Project imports
-from . import components, utils, exceptions, interfaces
+from m4us.core import components, utils, exceptions, interfaces
 
 
 #---Globals--------------------------------------------------------------------
@@ -97,8 +97,8 @@ class Graphline(components.Component):
     ...   (coroutine3, 'outbox', 'self', 'outbox'),
     ...   (coroutine3, 'signal', 'self', 'signal'),
     ... )
-    >>> scheduler.add(*graphline.coroutines)
-    >>> post_office.link(*graphline.links)
+    >>> scheduler.register(*graphline.coroutines)
+    >>> post_office.register(*graphline.links)
 
     In this example, `messages` sent to *graphline* will be forwarded on to
     *coroutine1*.  `Messages` from *coroutine1* will be sent to both
@@ -251,7 +251,7 @@ class Graphline(components.Component):
                 container = interfaces.IContainer(coroutine, None)
                 if container:
                     prepared_links.update(container.links)
-        return prepared_links
+        return frozenset(prepared_links)
 
     ## pylint: disable=R0201
     def _main(self):
@@ -304,8 +304,8 @@ class Pipeline(Graphline):
     Example:
 
     >>> pipeline = Pipeline(coroutine1, coroutine2, coroutine3)
-    >>> scheduler.add(*pipeline.coroutines)
-    >>> post_office.link(*pipeline.links)
+    >>> scheduler.register(*pipeline.coroutines)
+    >>> post_office.register(*pipeline.links)
 
     In this example, `messages` sent to *pipeline* will be forwarded on to
     *coroutine1*, who's `messages` will be sent to *coroutine2*, who's
