@@ -221,11 +221,11 @@ class IPostOfficeFactory(interface.Interface):
         """Return the desired `post office`.
 
         :param link_ignores_duplicates: If :obj:`True`, the
-          :meth:`IPostOffice.link` method becomes `idempotent` and will not
+          :meth:`IPostOffice.register` method becomes `idempotent` and will not
           raise an exception when adding an already added `link`.
         :type link_ignores_duplicate: :class:`bool`
         :param unlink_ignores_missing: If :obj:`True`, the
-          :meth:`IPostOffice.unlink` method becomes `idempotent` and will not
+          :meth:`*.unregister` method becomes `idempotent` and will not
           raise an exception when removing a `link` that was not already added.
         :type unlink_ignores_missing: :class:`bool`
 
@@ -249,7 +249,7 @@ class IPostOffice(interface.Interface):
 
     """
 
-    def link(first_link, *other_links):
+    def register(first_link, *other_links):
         """Register `links` between `coroutines`.
 
         When a `source` `coroutine`'s `outbox` is linked to a `sink`
@@ -284,7 +284,7 @@ class IPostOffice(interface.Interface):
 
         """
 
-    def unlink(first_link, *other_links):
+    def unregister(first_link, *other_links):
         """Unregister previously registered `links`.
 
         This is the opposite of the :meth:`link` method.
@@ -376,13 +376,13 @@ class ISchedulerFactory(interface.Interface):
           retrieve `messages`.
         :type post_office: :class:`IPostOffice`
         :param add_ignores_duplicates: If :obj:`True`, the
-          :meth:`IScheduler.add` method becomes `idempotent` and will not raise
-          an exception when adding an already added `coroutine`.
+          :meth:`IScheduler.register` method becomes `idempotent` and will not
+          raise an exception when adding an already added `coroutine`.
         :type add_ignores_duplicates: :class:`bool`
         :param remove_ignores_missing: If :obj:`True`, the
-          :meth:`IScheduler.remove` method becomes `idempotent` and will not
-          raise an exception when removing a `coroutine` that was not already
-          added.
+          :meth:`IScheduler.unregister` method becomes `idempotent` and will
+          not raise an exception when removing a `coroutine` that was not
+          already added.
         :type remove_ignores_missing: :class:`bool`
 
         :returns: The desired `scheduler`.
@@ -406,7 +406,7 @@ class IScheduler(interface.Interface):
 
     """
 
-    def add(first_coroutine, *other_coroutines):
+    def register(first_coroutine, *other_coroutines):
         """Register one or more `coroutines` with the `scheduler`.
 
         In order for a `scheduler` to run a `coroutine`, it must first be added
@@ -432,7 +432,7 @@ class IScheduler(interface.Interface):
 
         """
 
-    def remove(first_coroutine, *other_coroutines):
+    def unregister(first_coroutine, *other_coroutines):
         """Unregister one or more `coroutines` from the `scheduler`.
 
         This is the opposite of the :meth:`add` method.
@@ -591,9 +591,9 @@ class IContainer(interface.Interface):
     All containers should calculate and provide :attr:`~IContainer.coroutines`
     and :attr:`~IContainer.links` attributes before they are used. The contents
     of :attr:`~IContainer.coroutines` should be able to be passed to the
-    appropriate :meth:`IScheduler.add` method and the contents of
+    appropriate :meth:`IScheduler.register` method and the contents of
     :attr:`~IContainer.links` should be able to be passed to the appropriate
-    :meth:`~IPostOffice.link` method.
+    :meth:`~IPostOffice.register` method.
 
     Additionally, containers can contain other :class:`IContainer` objects, in
     other words other containers.  In such a case,
@@ -617,9 +617,9 @@ class IContainer(interface.Interface):
         The contained `coroutines` can be added to the `scheduler` with code
         similar to :samp:`{scheduler}.add(*{container}.coroutines)`.
 
-        :type: :class:`tuple` of :class:`ICoroutine`\s
+        :type: Immutable sequence of :class:`ICoroutine`\s
 
-        .. seealso:: :meth:`IScheduler.add` for details about adding
+        .. seealso:: :meth:`IScheduler.register` for details about adding
             `coroutines` to `schedulers`.
 
         """)
@@ -632,12 +632,12 @@ class IContainer(interface.Interface):
 
         The `links` between the contained `coroutines` can be added to the
         `post office` with code similar to
-        :samp:`{post_office}.link(*{container}.links)`.
+        :samp:`{post_office}.register(*{container}.links)`.
 
-        :type: :class:`set` of 4-:class:`tuple`\s
+        :type: Immutable sequence of 4-:class:`tuple`\s
 
-        .. seealso:: :meth:`IPostOffice.link` for details about adding `links`
-            to `post offices`.
+        .. seealso:: :meth:`IPostOffice.register` for details about adding
+            `links` to `post offices`.
 
         """)
 
