@@ -40,6 +40,7 @@ import subprocess
 import webbrowser
 import re
 import codecs
+import sys
 
 #---  Third-party imports
 import paver.easy as paver
@@ -55,16 +56,9 @@ except ImportError:
 
 #---Globals--------------------------------------------------------------------
 
-_TESTS_REQUIRE = [
-  'nose>=1.0,<1.0.99',
-  'mock>=0.6,<0.6.99',
-  'unittest2>=0.5.1,<0.5.99',
-  'strait>=0.5.1,<0.5.99',
-]
-
 _SETUP = dict(
   name='m4us',
-  version='0.1.1',
+  version='0.2',
   description=('A pythonic coroutine-based concurrent programming framework '
     'inspired by Kamaelia.'),
   author='Krys Lawrence',
@@ -74,17 +68,18 @@ _SETUP = dict(
   zip_safe=True,
   ##namespace_packages=[],
   ##test_loader='',
-  test_suite='nose.collector',
+  test_suite='unittest2.collector',
   install_requires=[
     'zope.interface>=3.6.1,<3.6.99',
-    'zope.component>=3.10,<3.10.99',
     'decorator>=3.2.1,<3.2.99',
+    # Test dependencies.  The tests can be run anywhere.
+    'unittest2>=0.5.1,<0.5.99',
+    'mock>=0.7b4,<0.7.99',
     # Sub-dependencies
-    'zope.event>=3.5,<3.5.99',
   ],
   ##extras_require={},
   ##setup_requires=[],
-  tests_require=_TESTS_REQUIRE,
+  ##tests_require=[],
   ##dependency_links=[],
   ##eager_resources=[],
   ##entry_points={},
@@ -108,15 +103,18 @@ _OPTIONS = dict(
   sphinx=paver.Bunch(builddir='', sourcedir='source'),
   purge=paver.Bunch(exclude_patterns=['*.wpu']),
   pep8=paver.Bunch(paths=['m4us', 'pavement.py']),
-  flakes=paver.Bunch(paths=['m4us', 'pavement.py']),
   lint=paver.Bunch(paths=['m4us', 'pavement.py']),
   tests_lint=paver.Bunch(paths=['m4us.core.tests', 'm4us.tests']),
   clones=paver.Bunch(packages=['m4us']),
+  flakes=paver.Bunch(
+    paths=['m4us', 'pavement.py'],
+    other_regexes=[r'[/\\\.]api\.py:', "'init' imported but unused"],
+  ),
   virtualenv=paver.Bunch(
     no_site_packages=True,
     paver_command_line='develop',
     use_distribute=True,
-    packages_to_install=_TESTS_REQUIRE + [
+    packages_to_install=[
       'virtualenv>=1.5.1,<1.5.99',
       'ipython>=0.10.1,<0.10.99',
       'Sphinx>=1.0.5,<1.0.99',
@@ -219,6 +217,11 @@ def _gen_docs(options, *option_sets):
     paverutils.run_sphinx(options, *option_sets)
 
 
+def _in_setup_py():
+    """Return True when running as setup.py and not as "paver <some_task>"."""
+    return sys.modules['__main__'].__file__ == 'setup.py'
+
+
 #---  Tasks
 
 @paver.task
@@ -414,7 +417,7 @@ def coverage(options):
       'docs/coverage/index.html'))
     options.order()
     paver.sh('coverage erase')
-    paver.sh('coverage run {0} bin/nosetests 2>&1'.format(branch),
+    paver.sh('coverage run {0} bin/unit2 discover 2>&1'.format(branch),
       ignore_error=True)
     paver.sh('coverage html')
     paver.sh('coverage report -m')
@@ -474,7 +477,7 @@ def flakes(options):
     paths = options.paths
     ignore_unused_imports_for = options.get('ignore_unused_imports_for',
       ('map', 'zip', 'hex', 'ascii', 'oct', 'filter'))
-    other_regexes = options.get('other_regexes', (r'[/\\\.]api\.py:',))
+    other_regexes = options.get('other_regexes', ())
     unfiltered = options.get('unfiltered', False)
     options.order()
     results = paver.sh('pyflakes ' + ' '.join(paths), capture=True,
@@ -495,43 +498,75 @@ def flakes(options):
 
 @paver.task
 @paver.cmdopts([
-  ('only_errors', 'e', 'Only show errors.  No warning, reports, etc.'),
+  ('no_colour', 'c', 'Do not use colours in the output.'),
+  ('no_reports', 'r', 'Do not show the reports.'),
+  ('filter_disables', 'd', 'Filter out "Locally disabling..." messages'),
+  ('filter_empty', 'e', 'Filter out module headers with no messages.'),
 ])
 def lint(options):
     """Run pylint on the code."""
     options.order('lint')
     paths = options.paths
-    only_errors = options.get('only_errors', False)
     rcfile = options.get('rcfile', None)
+    no_colour = options.get('no_colour', False)
+    no_reports = options.get('no_reports', False)
+    filter_disables = options.get('filter_disables', False)
+    filter_empty = options.get('filter_empty', False)
     options.order()
     command = ['pylint']
-    if only_errors:
-        command.append('-E')
     if rcfile is not None:
         command.append('--rcfile=' + rcfile)
+    if no_colour:
+        command.append('-f text')
+    if no_reports:
+        command.append('-r n')
     command += paths
     # We capture the results and then print them so that output is in the
     # correct order when tasks are chained and the output is piped.
     # The consequence, however, is that paver.sh can hang if the output is too
     # much.  This is a bug in Paver.
     results = paver.sh(' '.join(command), capture=True, ignore_error=True)
+    if filter_disables:
+        results = results.splitlines()
+        results = [line for line in results if 'Locally disabling' not in line]
+        results = '\n'.join(results)
+    if filter_empty:
+        filtered_results = []
+        header_line = None
+        for line in results.splitlines():
+            if '*' * 13 in line:
+                header_line = line
+                continue
+            if line == '':
+                header_line = None
+            if header_line:
+                filtered_results.append(header_line)
+                header_line = None
+            filtered_results.append(line)
+        results = '\n'.join(filtered_results)
     print(results)
 
 
 @paver.task
-@paver.cmdopts([
-  ('only_errors', 'e', 'Only show errors.  No warning, reports, etc.'),
-])
+## pylint: disable=E1101
+@paver.cmdopts(lint.user_options)
+## pylint: enable=E1101
 def tests_lint(options):
     """Run pylint on the tests."""
     options.order('tests_lint')
     paths = options.paths
-    only_errors = options.get('only_errors', False)
     rcfile = options.get('rcfile', 'tests_pylintrc')
+    no_colour = options.get('no_colour', False)
+    no_reports = options.get('no_reports', False)
+    filter_disables = options.get('filter_disables', False)
+    filter_empty = options.get('filter_empty', False)
     options.order()
     options.setdotted('lint.paths', paths)
-    options.setdotted('lint.only_errors', only_errors)
     options.setdotted('lint.rcfile', rcfile)
+    options.setdotted('lint.no_colour', no_colour)
+    options.setdotted('lint.no_reports', no_reports)
+    options.setdotted('lint.filter_disables', filter_disables)
+    options.setdotted('lint.filter_empty', filter_empty)
     ## pylint: disable=E1120
     lint()
     ## pylint: enable=E1120
@@ -539,23 +574,28 @@ def tests_lint(options):
 
 @paver.task
 @paver.cmdopts([
-  ('full', 'f', 'Generate a full report'),
-  ('unfiltered', 'u', 'Do not filter pyflakes'),
+  ('full', 'f', 'Generate a full report.'),
+  ('no_colour', 'c', 'Do not use colours in the output.'),
 ])
 def check(options):
-    """Run pep8, pyflakes and pylint to find code smell."""
+    """Run pep8, pyflakes and pylintto find code smell."""
     options.order('check')
     full = options.get('full', False)
-    unfiltered = options.get('unfiltered', False)
+    no_colour = options.get('no_colour', False)
     options.order()
     if full:
         options.setdotted('pep8.source', True)
         options.setdotted('pep8.pep', True)
     else:
-        options.setdotted('lint.only_errors', True)
-        options.setdotted('tests_lint.only_errors', True)
-    if unfiltered:
-        options.setdotted('flakes.unfiltered', True)
+        options.setdotted('lint.no_reports', True)
+        options.setdotted('lint.filter_disables', True)
+        options.setdotted('tests_lint.no_reports', True)
+        options.setdotted('tests_lint.filter_disables', True)
+        options.setdotted('lint.filter_empty', True)
+        options.setdotted('tests_lint.filter_empty', True)
+    if no_colour:
+        options.setdotted('lint.no_colour', True)
+        options.setdotted('tests_lint.no_colour', True)
     ## pylint: disable=E1120
     pep8()
     flakes()
@@ -616,6 +656,23 @@ def readme(options):
           webbrowser.open, output_file)
 
 
+if not _in_setup_py():
+    @paver.task
+    @paver.consume_args
+    def test(args):
+        """Replacement for distutils command that works in paver.
+
+        This task is not needed or available when running commands and tasks
+        from setup.py.  The default disutils command is used instead.  (e.g.
+        "python setup.py test".
+
+        When run from paver (e.g. "paver test"), however, unittest2's test
+        collector gets confused.  This task works around that.
+
+        """
+        paver.sh(' '.join(['unit2', 'discover'] + args))
+
+
 #---Classes--------------------------------------------------------------------
 
 
